@@ -18,8 +18,10 @@ fn pineappl(_py: Python, m: &PyModule) -> PyResult<()> {
     m.add_class::<lumi::PyLumiEntry>()?;
     m.add_class::<import_only_subgrid::PyImportOnlySubgridV1>()?;
     m.add_class::<fk_table::PyFkTable>()?;
+    m.add_class::<fk_table::PyFkAssumptions>()?;
     m.add_class::<subgrid::PySubgridEnum>()?;
     m.add_class::<subgrid::PySubgridParams>()?;
+    m.add("version", env!("CARGO_PKG_VERSION"))?;
 
     Ok(())
 }
